@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # import params is just one 'no-unicode-escape-permanently'
 # if set, then unicode escaping will not happen at
@@ -566,7 +566,7 @@ Data::Roundtrip - convert between Perl data structures, YAML and JSON with unico
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -759,7 +759,7 @@ calls to each of the C<< *2dump* >> subs under
 and for C<< 'dont-bloody-escape-unicode' => 0 >> and
 C<< 'dont-bloody-escape-unicode' => 1 >>.
 
-In general, L<perl2dum> is faster by 25% when one of the
+In general, L</perl2dump> is faster by 25% when one of the
 permanent import parameters is used
 (either of the last two cases above).
 
@@ -925,11 +925,10 @@ The output can be fed back to L</dump2perl>.
 
 CAVEAT: when not escaping unicode (which is the default
 behaviour), each call to this sub will override L<Data::Dumper>'s
-C<qquote()> sub
-(with a call to L<Sub::Override>' C<< new() >> ),
+C<qquote()> sub then
 call L<Data::Dumper>'s C<Dumper()> and save its output to
-a temporary variable, restore C<qquote()> sub (with
-a call to L<Sub::Override>'s C<< restore() >> and return the
+a temporary variable, restore C<qquote()> sub to its original
+code ref and return the
 contents. This exercise is done every time this C<perl2dump()>
 is called. It may be expensive. The alternative is
 to redefine C<qquote()> once, when the module is loaded, with
